*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Indicadores de Agua, Saneamiento e Higiene (ASH)					     	   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Empleo, Desempleo y Subempleo (ENEMDU)		   		   *
* UNIDAD TÉCNICA RESPONSABLE: 												   *
* Dirección de Innovación en Métricas y Metodologías (DINME)			   	   *
* ENTIDAD EJECUTORA:														   *
* Instituto Nacional de Estadística y Censos (INEC)							   *
*==============================================================================*
* Fecha de elaboración 10/06/2019     										   *
* Fecha última  modificación 10/06/2019										   *
*==============================================================================*
* Elaborado por:															   *
* Mónica Pozo                                                                  *
* Juan José Viteri															   *
* Analistas de DINME														   *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* monica_pozo@inec.gob.ec													   *
* juan_viteri@inec.gob.ec                                                      *
* Revisado por:																   *
* Lorena Moreno                                                                *
* Directora de DINME                                                           *
* lorena_moreno@inec.gob.ec                                                    *
*==============================================================================*

clear all
set more off

** cd  =INCLUIR DIRECTORIO==
cd "............"

** INCLUIR EL NOMBRE DE LA BASE DE DATOS el nombre de la base de datos
use "bdd_ash2019", clear

*INDICADORES A NIVEL DE PERSONA
*Nota: Para calcular los indicadores a nivel de persona se debe correr: 		
svyset id_upm [iw = fexpper], strata(plan_muestreo) vce(linearized) singleunit(certainty)


*    			INDICADORES ODS DE AGUA, SANEAMIENTO E HIGIENE                 *
*==============================================================================*
*									AGUA                                       *
*==============================================================================*
*========================================================================================*
*Indicador 6.1.1 Porcentaje de hogares que utiliza suministros seguros de agua para beber
*========================================================================================*
/* Componentes del indicador: 1) tipo de suministro
							  2) calidad del agua
							  3) cercanía del suministro
							  4) suficiencia de agua para beber */

*==============================================================================*
*									FUENTE									   *							 
*==============================================================================*
* 1. Tipo de suministro

recode vi16 (1/3   =1 "tuberia")(4/7   =2 "Otro"), gen(vi16r)

recode vi17 (1/3 7 9    = 1 "tipo A") ///
            (4 8 10 12  = 2 "tipo B") ///
			(11 13      = 3 "tipo C"), gen(agua_cp1) 
label var agua_cp1 "tipo de suministro"	
replace agua_cp1 = 1 if inlist(vi17,5,6) & vi16r==1
replace agua_cp1 = 2 if inlist(vi17,5,6) & vi16r==2

/* 2. Calidad del agua -libre de contaminaci󮠦ecal (bacteria E. coli)
 ra01e_f : Horas de incubación entre 24 y 48 horas
 ra022_f: La muestra de agua tiene coloraci󮠡marilla?
 ra023_f: La muestra se hizo fluorescente al exponerse a la luz uv?
 ra03_f: Hubo una pérdida de más del 10 % (10ml) del contenido de la muestra de agua?
 ra04_f: Estuvo la muestra expuesta a temperaturas menores a 30Рo mayores a 40Рpor mⳠde 4 horas? */

 
	* Se identifican pruebas válidas fuente
	gen     validtest_f = 0 if vi26==1 & ra01e_f!=. 
	replace validtest_f = 1 if inrange(ra01e_f,24,48) & ra03_f==2 & ra04_f==2
	replace validtest_f = 2 if vi26==2
	
	
    label def validtest_f 0 "no" 1 "si" 2 "rechazo", replace
	label val validtest_f validtest_f
	label var validtest_f "Prueba válida fuente?"
		
	* Presencia de coliformes fuente
	gen      coli_f =0 if validtest==1
	replace  coli_f =1 if validtest==1 & ra022_f==1
	replace  coli_f =2 if validtest==1 & ra022_f==2
	label def coli_f 1 "si" 2 "no", replace
	label val coli_f coli_f
	label var coli_f "presencia de coliformes fuente"
		
	* Ausencia de E. coli fuente
	gen     agua_cp2_f =0 if validtest_f==1 
	replace agua_cp2_f =1 if validtest_f==1 & (ra023_f==2 | ra022_f==2)
	replace agua_cp2_f =2 if validtest_f==1 & ra023_f==1
	label def agua_cp2_f 1 "si" 2 "no", replace
	label val agua_cp2_f agua_cp2_f
	label var agua_cp2_f "calidad del agua en la fuente"

* 3. Cercanía del suministro
gen     agua_cp3 = 0 
replace agua_cp3 = 1 if inlist(vi17a,1,2) 
replace agua_cp3 = 1 if inlist(vi17,5,6)
* Nota.- el supuesto es que el agua embotellada estᡣerca para el consumo
replace agua_cp3 = 2 if vi17a==3 & vi17b <=30
replace agua_cp3 = 3 if vi17a==3 & vi17b > 30 // incluye la categorno sabe 999

* Se  encuentra fuera de la vivienda, edifico/lote y no sabe a cuanto se encuentra (en minutos) la fuente 
replace agua_cp3 = . if vi17b==999 & (vi17a!=1 | vi17a!=2) 

lab def agua_cp3 ///
1 "terreno/edificio" ///
2 "menos o igual a 30 min" ///
3 "más de 30 min", replace
label values agua_cp3 agua_cp3
label var agua_cp3 "cercanía del suministro"

* 4. Suficiencia de agua para beber
gen     agua_cp4 = 0
replace agua_cp4 = 1 if vi17c==1
replace agua_cp4 = 2 if vi17c >1
replace agua_cp4 = . if vi17c==3
label def agua_cp4 1 "continuo" 2 "no continuo", replace
label val agua_cp4 agua_cp4
label var agua_cp4 "continuidad del suministro"

*==============================================================================*

cap drop i_agua
gen i_agua = 0 if !mi(agua_cp1) & !mi(agua_cp2) & !mi(agua_cp3) & !mi(agua_cp4) 

* manejo seguro
replace i_agua = 1 if agua_cp1==1 & agua_cp2==1 & agua_cp3==1 & agua_cp4==1
* básico 1
replace i_agua = 2 if agua_cp1==1 & agua_cp2==1 & agua_cp3==1 & agua_cp4==2 /**/
replace i_agua = 2 if agua_cp1==1 & agua_cp2==1 & agua_cp3==2 /**/
* básico 2
replace i_agua = 3 if agua_cp1==1 & agua_cp2==2 & agua_cp3==1 /**/
replace i_agua = 3 if agua_cp1==1 & agua_cp2==2 & agua_cp3==2 /**/
* limitado
replace i_agua = 4 if agua_cp1==1 				& agua_cp3==3 
* no mejorado
replace i_agua = 5 if agua_cp1==2
* superficial
replace i_agua = 6 if agua_cp1==3

label def i_agua ///
1 "seguro" ///
2 "básico 1" ///
3 "básico 2" ///
4 "limitado" ///
5 "no mejorado" ///
6 "superficial", replace
label values i_agua i_agua
label var i_agua "Servicios de agua para beber manejado de forma segura"

*==============================================================================*
*							PUNTO DE CONSUMO (VASO)	         				   *							 
*==============================================================================*
	 * Se identifican pruebas válidas vaso
	gen     validtest_v = 0 if vi21==1 & ra01e_v!=.
	replace validtest_v = 1 if inrange(ra01e_v,20,48) & ra03_v==2 & ra04_v==2
	replace validtest_v = 2 if vi21==2 
	
    label def validtest_v 0 "no" 1 "si" 2 "rechazo", replace
	label val validtest_v validtest
	label var validtest_v "prueba válida vaso?"
	
	* Presencia de coliformes vaso
	gen      coli_v =0 if validtest_v==1
	replace  coli_v =1 if validtest_v==1 & ra022_v==1
	replace  coli_v =2 if validtest_v==1 & ra022_v==2
	label def coli_v 1 "si" 2 "no", replace
	label val coli_v coli_v
	label var coli_v "presencia de coliformes vaso"
		
	* Ausencia de E. coli vaso
	gen     agua_cp2_v =0 if validtest_v==1 
	replace agua_cp2_v =1 if validtest_v==1 & (ra023_v==2 | ra022_v==2)
	replace agua_cp2_v =2 if validtest_v==1 & ra023_v==1
	label def agua_cp2_v 1 "si" 2 "no", replace
	label val agua_cp2_v agua_cp2_v
	label var agua_cp2_v "calidad del agua en el vaso"

*==============================================================================*
*									SANEAMIENTO                                *
*==============================================================================*
* Indicador 6.2.1: Porcentaje de hogares que usa servicios de saneamiento básico
*==============================================================================*

/* Componentes del indicador: 1) tipo de sistema de saneamiento
							 2) exclusividad del servicio,
							 3) manejo de desechos */

*1. Tipo de sistema de saneamiento

* Saneamiento básico
gen sanea_cp1 = 0
* Excusado y alcantarillado: 
replace sanea_cp1 =1 if vi13==1
* Excusado y pozo séptico:
replace sanea_cp1 =2 if vi13==2
* Excusado y pozo ciego: 
replace sanea_cp1 =3 if vi13==3 
* Letrina con losa:
replace sanea_cp1 =4 if vi13==4 & vi13b==1
* Letrina sin losa
replace sanea_cp1 =5 if vi13==4 & vi13b==2
* Prestado 1 - alcantarillado, pozo séptico, pozo ciego
replace sanea_cp1 =6 if vi13==5 & vi13d==2 & inrange(vi14,1,3)
* Prestado 2 - letrina
replace sanea_cp1 =7 if vi13==5 & vi13d==2 & vi14==4
* No tiene 
replace sanea_cp1 =8 if vi13==5 & vi13d==1

lab def sanea_cp1 ///
1 "Alcantarillado" ///
2 "Pozo séptico" ///
3 "Pozo ciego" ///
4 "Letrina con losa" ///
5 "Letrina sin losa" ///
6 "Prestado 1" ///
7 "Prestado 2" ///
8 "No tiene", replace 
label values sanea_cp1 sanea_cp1

* 2. exclusividad del servicio
gen sanea_cp2 =0
replace sanea_cp2 =1 if vi15==2
replace sanea_cp2 =2 if vi15==1 | vi13==5
lab def sanea_cp2 ///
1 "exclusivo" ///
2 "compartido", replace
label values sanea_cp2 sanea_cp2
label var sanea_cp2 "uso del servicio"	

* 3. Manejo de excretas
gen sanea_cp3 =0
* Excusado y alcantarillado: 
replace sanea_cp3 =2 if vi13==1
 /* Nota.- No es posible estimar directamente. Por lo que no se puede clasificar 
 como manejo seguro*/
   
* Excusado y pozo séptico / ciego:
replace sanea_cp3 =1 if inlist(vi13,2,3) & inlist(vi13a,2,3,4) & vi13c==2
replace sanea_cp3 =2 if inlist(vi13,2,3) & inlist(vi13a,2,3,4) & vi13c==1
replace sanea_cp3 =2 if inlist(vi13,2,3) & vi13a ==1
* Letrina con losa y sin losa:
replace sanea_cp3 =1 if vi13==4 & vi13c==2
*replace sanea_cp3 =2 if vi13==4 & inlist(vi13c,1,3)
replace sanea_cp3 =2 if vi13==4 & vi13c==1
*Missing si responde "no sabe" en 13c dependiendo de la condición
replace sanea_cp3 =. if inlist(vi13,2,3) & inlist(vi13a,2,3,4) & vi13c==3
replace sanea_cp3 =. if vi13==4 & vi13b==1 & vi13c==3
replace sanea_cp3 =. if vi13==5

lab def sanea_cp3 ///
1 "seguro" ///
2 "no seguro", replace
label values sanea_cp3 sanea_cp3
label var sanea_cp3 "manejo de excretas"       

*====================================================================================
cap drop i_sanea
gen i_sanea = 0 if !mi(sanea_cp1) & !mi(sanea_cp2) & !mi(sanea_cp3)

* básico
replace i_sanea = 1 if inrange(sanea_cp1,1,4) & sanea_cp2==1 & sanea_cp3==1
replace i_sanea = 1 if inrange(sanea_cp1,1,4) & sanea_cp2==1 & sanea_cp3==2
* limitado
replace i_sanea = 2 if inlist(sanea_cp1,1,4)  & sanea_cp2==2 
replace i_sanea = 2 if inlist(sanea_cp1,2,3)  & sanea_cp2==2 & sanea_cp3==1
replace i_sanea = 2 if sanea_cp1==6
* no mejorado
replace i_sanea = 3 if inrange(sanea_cp1,2,4) & sanea_cp2==2 & sanea_cp3==2
replace i_sanea = 3 if inlist(sanea_cp1,5,7)
* al aire libre
replace i_sanea = 4 if sanea_cp1==8
 
lab def i_sanea ///
1 "básico" ///
2 "limitado" ///
3 "no mejorado" ///
4 "al aire libre", replace
label values i_sanea i_sanea
label var i_sanea "servicios de saneamiento - ODS"   

*==============================================================================*
*									HIGIENE    	                               *
*==============================================================================*
*==================================================================================*
* Indicador 6.2.2: Porcentaje de hogares que dispone de una instalación para lavarse          *
* las manos con agua y jabón                                                               *
*==================================================================================*

*Higiene

* 1.Instalación
gen higiene_cp1=0
replace higiene_cp1 = 1 if vi29==1
replace higiene_cp1 = 2 if vi29==2 & inlist(vi32,1,3)
*No permite la observación
replace higiene_cp1 = . if vi29==2 & vi32==2
*otras razones
replace higiene_cp1 = . if vi29==2 & vi32==4

lab def higiene_cp1 ///
1 "Con instalación" ///
2 "Sin instalación", replace
lab values higiene_cp1 higiene_cp1
label var higiene_cp1 "Instalación para lavarse las manos"	

* 2.Agua
gen higiene_cp2=0
replace higiene_cp2 = 1 if vi29==1 & vi30==1
replace higiene_cp2 = 2 if vi29==1 & vi30==2
replace higiene_cp2 = 2 if vi29==2 & inlist(vi32,1,3)
replace higiene_cp2 = . if vi29==2 & vi33==1
replace higiene_cp2 = . if vi29==2 & vi33==2
replace higiene_cp2 = . if vi29==2 & vi32==3 & vi33==.

lab def higiene_cp2 ///
1 "Si tiene agua" ///
2 "No tiene agua", replace
lab values higiene_cp2 higiene_cp2
label var higiene_cp2 "Agua para lavarse las manos"

* 3.Jabón

gen higiene_cp3=0
replace higiene_cp3 = 1 if vi29==1 & ((vi31a==1 | vi31b==1) & (vi31e==2))
replace higiene_cp3 = 2 if vi29==1 & (vi31a!=1 & vi31b!=1)
replace higiene_cp3 = 2 if vi29==2 & inlist(vi32,1,3)
replace higiene_cp3 = . if vi29==2 

lab def higiene_cp3 ///
1 "Si tiene jabón" ///
2 "No tiene jabón", replace
lab values higiene_cp3 higiene_cp3
label var higiene_cp3 "Jabón para lavarse las manos"

*====================================================================================

cap drop i_higiene
gen i_higiene = 0 if  !mi(higiene_cp1) | !mi(higiene_cp2) | !mi(higiene_cp3)

*básico
replace i_higiene = 1 if higiene_cp1==1 & higiene_cp2==1 & higiene_cp3==1

*limitado
replace i_higiene = 2 if higiene_cp1==1 & higiene_cp2==1 & higiene_cp3==2
replace i_higiene = 2 if higiene_cp1==1 & higiene_cp2==2 & higiene_cp3==1
replace i_higiene = 2 if higiene_cp1==1 & higiene_cp2==2 & higiene_cp3==2

*sin instalación
replace i_higiene = 3 if higiene_cp1==2

lab def i_higiene ///
1 "básico" ///
2 "limitado" ///
3 "sin instalación", replace
lab values i_higiene i_higiene
label var i_higiene "presencia de agua y jabon - ODS"

*==============================================================================*
*									FIN      	                               *
*==============================================================================*	  
